@@ -307,32 +307,34 @@ RUN /root/.local/bin/uv pip install --system cuti \\
         except Exception as e:
             print(f"⚠️  Could not set permissions: {e}")
         
-        # Copy important files from host .claude if they exist (one-time sync)
+        # Initial one-time sync from host .claude if container config is empty
         host_claude_dir = Path.home() / ".claude"
         
-        # Copy credentials (most important)
-        host_credentials = host_claude_dir / ".credentials.json"
+        # Only copy if this is first setup (no credentials in container config yet)
         container_credentials = container_claude_dir / ".credentials.json"
-        if host_credentials.exists() and not container_credentials.exists():
-            import shutil
-            shutil.copy2(host_credentials, container_credentials)
-            print("🔑 Synced Claude credentials from host to container config")
-        
-        # Copy CLAUDE.md if it exists
-        host_claude_md = host_claude_dir / "CLAUDE.md"
-        container_claude_md = container_claude_dir / "CLAUDE.md"
-        if host_claude_md.exists() and not container_claude_md.exists():
-            import shutil
-            shutil.copy2(host_claude_md, container_claude_md)
-            print("📄 Synced CLAUDE.md to container config")
-        
-        # Copy plugins config if it exists
-        host_plugins_config = host_claude_dir / "plugins" / "config.json"
-        container_plugins_config = container_claude_dir / "plugins" / "config.json"
-        if host_plugins_config.exists() and not container_plugins_config.exists():
-            import shutil
-            shutil.copy2(host_plugins_config, container_plugins_config)
-            print("🔌 Synced plugins config to container")
+        if not container_credentials.exists():
+            # Copy credentials if they exist on host
+            host_credentials = host_claude_dir / ".credentials.json"
+            if host_credentials.exists():
+                import shutil
+                shutil.copy2(host_credentials, container_credentials)
+                # Ensure copied file has proper permissions
+                container_credentials.chmod(stat.S_IRUSR | stat.S_IWUSR | stat.S_IRGRP | stat.S_IWGRP | stat.S_IROTH | stat.S_IWOTH)
+                print("🔑 Initial sync: Copied Claude credentials from host")
+            
+            # Copy CLAUDE.md if it exists
+            host_claude_md = host_claude_dir / "CLAUDE.md"
+            if host_claude_md.exists():
+                import shutil
+                shutil.copy2(host_claude_md, container_claude_dir / "CLAUDE.md")
+                print("📄 Initial sync: Copied CLAUDE.md from host")
+            
+            # Copy plugins config if it exists
+            host_plugins_config = host_claude_dir / "plugins" / "config.json"
+            if host_plugins_config.exists():
+                import shutil
+                shutil.copy2(host_plugins_config, container_claude_dir / "plugins" / "config.json")
+                print("🔌 Initial sync: Copied plugins config from host")
         
         # Create or update container-specific .claude.json
         container_claude_json = container_claude_dir / ".claude.json"
@@ -354,10 +356,11 @@ RUN /root/.local/bin/uv pip install --system cuti \\
         if container_credentials.exists():
             print(f"✅ Container Claude config ready at {container_claude_dir}")
             print("🔑 Claude credentials available - no login needed!")
+            print("📌 Config is directly mounted - changes persist automatically")
         else:
             print(f"⚠️  No saved credentials at {container_claude_dir}")
             print("   Authenticate once in container with: claude login")
-            print("   Credentials will persist across all containers")
+            print("   Credentials will persist across all containers and rebuilds")
         
         return container_claude_dir
     
@@ -494,7 +497,7 @@ RUN /root/.local/bin/uv pip install --system cuti \\
             "docker", "run", "--rm", "--privileged", 
             "-v", f"{current_dir}:/workspace:{mount_options}",  # Dynamic mount options
             "-v", f"{Path.home() / '.cuti'}:/root/.cuti-global", 
-            "-v", f"{container_claude_dir}:/host-claude-config:ro",  # Mount host's container claude dir as read-only
+            "-v", f"{container_claude_dir}:/home/cuti/.claude:rw",  # Direct mount for persistence
             "-v", "/var/run/docker.sock:/var/run/docker.sock",  # Mount Docker socket for Docker-in-Docker
             "-w", "/workspace",
             "--env", "CUTI_IN_CONTAINER=true",
@@ -539,25 +542,12 @@ else
     export CLAUDE_CONFIG_DIR=/home/cuti/.claude
 fi
 
-# Copy mounted claude config to a writable location if needed
-if [ -d /host-claude-config ]; then
-    # Remove existing .claude directory if it's a symlink or directory
-    rm -rf /home/cuti/.claude 2>/dev/null || true
-    
-    # Copy the mounted config to home directory
-    cp -r /host-claude-config /home/cuti/.claude 2>/dev/null || true
-    
-    # Ensure proper ownership
+# The .claude directory is now directly mounted from host, no need to copy
+# Just ensure proper ownership for the mounted directory
+if [ -d /home/cuti/.claude ]; then
+    # Fix ownership if needed (container user might have different UID/GID)
     sudo chown -R cuti:cuti /home/cuti/.claude 2>/dev/null || true
-    
-    # Create necessary Claude directories if they don't exist
-    mkdir -p /home/cuti/.claude/plugins/repos 2>/dev/null || true
-    mkdir -p /home/cuti/.claude/todos 2>/dev/null || true
-    mkdir -p /home/cuti/.claude/sessions 2>/dev/null || true
-    mkdir -p /home/cuti/.claude/projects 2>/dev/null || true
-    mkdir -p /home/cuti/.claude/statsig 2>/dev/null || true
-    mkdir -p /home/cuti/.claude/shell-snapshots 2>/dev/null || true
-    mkdir -p /home/cuti/.claude/ide 2>/dev/null || true
+    echo "🔗 Claude config directly mounted from host"
 fi
 
 # Handle workspace directories based on writability
@@ -570,49 +560,15 @@ if [ "$WORKSPACE_WRITABLE" = "true" ]; then
     sudo chown -R cuti:cuti /workspace/.claude 2>/dev/null || true
     sudo chown -R cuti:cuti /workspace/.cuti 2>/dev/null || true
     
-    # Copy credentials from host config if not present in workspace
-    if [ ! -f /workspace/.claude/.credentials.json ] && [ -f /home/cuti/.claude/.credentials.json ]; then
-        cp /home/cuti/.claude/.credentials.json /workspace/.claude/.credentials.json 2>/dev/null || true
-    fi
-    
-    echo "📁 Using workspace directories for Claude and cuti"
-else
-    # If read-only, copy workspace config to home if exists
-    if [ -d /workspace/.claude ]; then
-        echo "📁 Copying workspace .claude to home (workspace is read-only)..."
-        cp -rn /workspace/.claude/* /home/cuti/.claude/ 2>/dev/null || true
-        sudo chown -R cuti:cuti /home/cuti/.claude 2>/dev/null || true
-    fi
+    echo "📁 Using workspace directories for Claude queue storage"
 fi
 
-# Copy CLAUDE.md from workspace if it exists and not already present
-if [ -f /workspace/CLAUDE.md ] && [ ! -f /home/cuti/.claude/CLAUDE.md ]; then
-    cp /workspace/CLAUDE.md /home/cuti/.claude/CLAUDE.md 2>/dev/null || true
-fi
-
-# Check for existing credentials in the appropriate location
-if [ "$WORKSPACE_WRITABLE" = "true" ]; then
-    if [ -f /workspace/.claude/.credentials.json ]; then
-        echo "🔑 Found saved Claude credentials in workspace - no login needed!"
-    elif [ -f /home/cuti/.claude/.credentials.json ]; then
-        cp /home/cuti/.claude/.credentials.json /workspace/.claude/.credentials.json 2>/dev/null || true
-        echo "🔑 Copied credentials to workspace"
-    else
-        echo "⚠️  No saved credentials. Authenticate once with: claude login"
-        echo "   Your credentials will be saved in the workspace."
-    fi
+# Check for existing credentials in the mounted .claude directory
+if [ -f /home/cuti/.claude/.credentials.json ]; then
+    echo "🔑 Found saved Claude credentials - no login needed!"
 else
-    if [ -f /home/cuti/.claude/.credentials.json ]; then
-        echo "🔑 Found saved Claude credentials - no login needed!"
-    elif [ -f /workspace/.claude/.credentials.json ]; then
-        cp /workspace/.claude/.credentials.json /home/cuti/.claude/.credentials.json 2>/dev/null || true
-        echo "🔑 Copied credentials from workspace"
-    else
-        echo "⚠️  No saved credentials. Authenticate once with: claude login"
-        echo "   Your credentials will be saved for all future containers."
-    fi
-    # Ensure home storage directory exists for read-only mode
-    mkdir -p /home/cuti/.cuti 2>/dev/null || true
+    echo "⚠️  No saved credentials. Authenticate once with: claude login"
+    echo "   Your credentials will persist across all containers."
 fi
 
 # Ensure PYTHONPATH includes workspace source for local development
@@ -628,17 +584,6 @@ if [ -S /var/run/docker.sock ]; then
 else
     echo "⚠️  Docker socket not found - Docker commands won't work in container"
 fi
-
-# Function to sync credentials back to host on exit
-sync_credentials_to_host() {
-    if [ -d /host-claude-config ] && [ -f /home/cuti/.claude/.credentials.json ]; then
-        cp /home/cuti/.claude/.credentials.json /host-claude-config/.credentials.json 2>/dev/null || true
-        echo "📤 Synced credentials back to host"
-    fi
-}
-
-# Trap EXIT to sync credentials
-trap sync_credentials_to_host EXIT
 """
         
         # Add interactive flags if no specific command
